@@ -154,14 +154,14 @@ def test_style_output():
     class CliStyle(Style):
         default_style = ""
         styles = {
-            Token.Output.Header: 'bold #ansired',
+            Token.Output.Header: 'bold ansibrightred',
             Token.Output.OddRow: 'bg:#eee #111',
             Token.Output.EvenRow: '#0f0'
         }
     headers = ['h1', 'h2']
     data = [['观音', '2'], ['Ποσειδῶν', 'b']]
 
-    expected_headers = ['\x1b[31;01mh1\x1b[39;00m', '\x1b[31;01mh2\x1b[39;00m']
+    expected_headers = ['\x1b[91;01mh1\x1b[39;00m', '\x1b[91;01mh2\x1b[39;00m']
     expected_data = [['\x1b[38;5;233;48;5;7m观音\x1b[39;49m',
                       '\x1b[38;5;233;48;5;7m2\x1b[39;49m'],
                      ['\x1b[38;5;10mΠοσειδῶν\x1b[39m', '\x1b[38;5;10mb\x1b[39m']]
@@ -176,14 +176,14 @@ def test_style_output_with_newlines():
     class CliStyle(Style):
         default_style = ""
         styles = {
-            Token.Output.Header: 'bold #ansired',
+            Token.Output.Header: 'bold ansibrightred',
             Token.Output.OddRow: 'bg:#eee #111',
             Token.Output.EvenRow: '#0f0'
         }
     headers = ['h1', 'h2']
     data = [['观音\nLine2', 'Ποσειδῶν']]
 
-    expected_headers = ['\x1b[31;01mh1\x1b[39;00m', '\x1b[31;01mh2\x1b[39;00m']
+    expected_headers = ['\x1b[91;01mh1\x1b[39;00m', '\x1b[91;01mh2\x1b[39;00m']
     expected_data = [
         ['\x1b[38;5;233;48;5;7m观音\x1b[39;49m\n\x1b[38;5;233;48;5;7m'
          'Line2\x1b[39;49m',
@@ -200,14 +200,14 @@ def test_style_output_custom_tokens():
     class CliStyle(Style):
         default_style = ""
         styles = {
-            Token.Results.Headers: 'bold #ansired',
+            Token.Results.Headers: 'bold ansibrightred',
             Token.Results.OddRows: 'bg:#eee #111',
             Token.Results.EvenRows: '#0f0'
         }
     headers = ['h1', 'h2']
     data = [['1', '2'], ['a', 'b']]
 
-    expected_headers = ['\x1b[31;01mh1\x1b[39;00m', '\x1b[31;01mh2\x1b[39;00m']
+    expected_headers = ['\x1b[91;01mh1\x1b[39;00m', '\x1b[91;01mh2\x1b[39;00m']
     expected_data = [['\x1b[38;5;233;48;5;7m1\x1b[39;49m',
                       '\x1b[38;5;233;48;5;7m2\x1b[39;49m'],
                      ['\x1b[38;5;10ma\x1b[39m', '\x1b[38;5;10mb\x1b[39m']]
